==> magics++_2.8.0.dfsg.orig.tar.gz: magics++-2.8.0.dfsg/src/visualisers/ImagePlotting.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file ImagePlotting.h
    \brief Definition of the Template class ImagePlotting.
    
    Magics Team - ECMWF 2005
    
    Started: Wed 13-Apr-2005
    
    Changes:
    
*/

#ifndef ImagePlotting_H
#define ImagePlotting_H

#include "magics.h"

#include "Visdef.h"
#include "ImagePlottingAttributes.h"


namespace magics {
	

template <class P>
class ImagePlotting: public Visdef<P>, public ImagePlottingAttributes {

public:
	ImagePlotting();
	virtual ~ImagePlotting();
	
	virtual void operator()(Data<P>&, BasicGraphicsObjectContainer&);
	
	void set(const map<string, string>& map) { ImagePlottingAttributes::set(map); }
	void set(const XmlNode& node) { ImagePlottingAttributes::set(node); }
	ImagePlotting<P>* clone() const { 
		ImagePlotting<P>* object = new ImagePlotting<P>();
		object->copy(*this);
		return object;
	}
	
	void visit(LegendVisitor&);

	bool reproject(RasterData<P>& in, RasterData<P>& out, Transformation&, double, double);
		
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
	 vector<LegendEntry* > legend_;
	 

private:
    //! Copy constructor - No copy allowed
	ImagePlotting(const ImagePlotting&);
    //! Overloaded << operator to copy - No copy allowed
	ImagePlotting& operator=(const ImagePlotting&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const ImagePlotting<P>& p)
		{ p.print(s); return s; }

	bool createOutputRaster(const BasicGraphicsObjectContainer&, RasterData<P>&, RasterData<P>& );
};

} // namespace magics

#include "ImagePlotting.cc"
#endif

==> magics++_2.18.15.orig.tar.gz: magics++-2.18.15/src/visualisers/ImagePlotting.h <==
/******************************** LICENSE ********************************

 Copyright 2007 European Centre for Medium-Range Weather Forecasts (ECMWF)

 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at 

    http://www.apache.org/licenses/LICENSE-2.0

 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.

 ******************************** LICENSE ********************************/

/*! \file ImagePlotting.h
    \brief Definition of the Template class ImagePlotting.
    
    Magics Team - ECMWF 2005
    
    Started: Wed 13-Apr-2005
    
    Changes:
    
*/

#ifndef ImagePlotting_H
#define ImagePlotting_H

#include "magics.h"

#include "Visdef.h"
#include "ImagePlottingAttributes.h"
#include "LegendVisitor.h"

namespace magics {
	


class ImagePlotting: public Visdef, public ImagePlottingAttributes {

public:
	ImagePlotting();
	virtual ~ImagePlotting();
	
	virtual void operator()(Data&, BasicGraphicsObjectContainer&);
	
	void set(const map<string, string>& map) { ImagePlottingAttributes::set(map); }
	void set(const XmlNode& node) { ImagePlottingAttributes::set(node); }
	ImagePlotting* clone() const {
		ImagePlotting* object = new ImagePlotting();
		object->copy(*this);
		return object;
	}
	
	void visit(LegendVisitor&);

	bool reproject(RasterData& in, RasterData& out, Transformation&, double, double);
		
protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
	 virtual void print(ostream&) const; 
	 vector<LegendEntry* > legend_;
	 

private:
    //! Copy constructor - No copy allowed
	ImagePlotting(const ImagePlotting&);
    //! Overloaded << operator to copy - No copy allowed
	ImagePlotting& operator=(const ImagePlotting&);
    
// -- Friends
    //! Overloaded << operator to call print().
	friend ostream& operator<<(ostream& s,const ImagePlotting& p)
		{ p.print(s); return s; }

	bool createOutputRaster(const BasicGraphicsObjectContainer&, RasterData&, RasterData& );
};

} // namespace magics


#endif
